@@ -20,8 +20,6 @@ extern "C" {
 #include <gensio/gensio_dllvisibility.h>
 #include <gensio/gensio.h>
 
-struct sergensio;
-
 /*
  * Cast between sergensio and gensio types.  If
  */
@@ -30,6 +28,13 @@ struct gensio *sergensio_to_gensio(struct sergensio *sio);
 GENSIO_DLL_PUBLIC
 struct sergensio *gensio_to_sergensio(struct gensio *io);
 
+GENSIO_DLL_PUBLIC
+struct gensio_accepter *sergensio_acc_to_gensio_acc(
+		struct sergensio_accepter *sacc);
+GENSIO_DLL_PUBLIC
+struct sergensio_accepter *gensio_acc_to_sergensio_acc(
+		struct gensio_accepter *acc);
+
 typedef void (*sergensio_done)(struct sergensio *sio, int err,
 			       unsigned int val, void *cb_data);
 
@@ -60,11 +65,11 @@ GENSIO_DLL_PUBLIC
 int sergensio_datasize(struct sergensio *sio, unsigned int datasize,
 		       sergensio_done done, void *cb_data);
 
-#define SERGENSIO_PARITY_NONE	1
-#define SERGENSIO_PARITY_ODD	2
-#define SERGENSIO_PARITY_EVEN	3
-#define SERGENSIO_PARITY_MARK	4
-#define SERGENSIO_PARITY_SPACE	5
+#define SERGENSIO_PARITY_NONE	1u
+#define SERGENSIO_PARITY_ODD	2u
+#define SERGENSIO_PARITY_EVEN	3u
+#define SERGENSIO_PARITY_MARK	4u
+#define SERGENSIO_PARITY_SPACE	5u
 GENSIO_DLL_PUBLIC
 int sergensio_parity(struct sergensio *sio, unsigned int parity,
 		     sergensio_done done, void *cb_data);
@@ -73,38 +78,69 @@ GENSIO_DLL_PUBLIC
 int sergensio_stopbits(struct sergensio *sio, unsigned int stopbits,
 		       sergensio_done done, void *cb_data);
 
-#define SERGENSIO_FLOWCONTROL_NONE	1
-#define SERGENSIO_FLOWCONTROL_XON_XOFF	2
-#define SERGENSIO_FLOWCONTROL_RTS_CTS	3
+#define SERGENSIO_FLOWCONTROL_NONE	1u
+#define SERGENSIO_FLOWCONTROL_XON_XOFF	2u
+#define SERGENSIO_FLOWCONTROL_RTS_CTS	3u
 GENSIO_DLL_PUBLIC
 int sergensio_flowcontrol(struct sergensio *sio, unsigned int flowcontrol,
 			  sergensio_done done, void *cb_data);
 
-#define SERGENSIO_FLOWCONTROL_DCD	4
-#define SERGENSIO_FLOWCONTROL_DTR	5
-#define SERGENSIO_FLOWCONTROL_DSR	6
+#define SERGENSIO_FLOWCONTROL_DCD	4u
+#define SERGENSIO_FLOWCONTROL_DTR	5u
+#define SERGENSIO_FLOWCONTROL_DSR	6u
 GENSIO_DLL_PUBLIC
 int sergensio_iflowcontrol(struct sergensio *sio, unsigned int iflowcontrol,
 			   sergensio_done done, void *cb_data);
 
-#define SERGENSIO_BREAK_ON	1
-#define SERGENSIO_BREAK_OFF	2
+#define SERGENSIO_BREAK_ON	1u
+#define SERGENSIO_BREAK_OFF	2u
 GENSIO_DLL_PUBLIC
 int sergensio_sbreak(struct sergensio *sio, unsigned int breakv,
 		     sergensio_done done, void *cb_data);
 
-#define SERGENSIO_DTR_ON	1
-#define SERGENSIO_DTR_OFF	2
+#define SERGENSIO_DTR_ON	1u
+#define SERGENSIO_DTR_OFF	2u
 GENSIO_DLL_PUBLIC
 int sergensio_dtr(struct sergensio *sio, unsigned int dtr,
 		  sergensio_done done, void *cb_data);
 
-#define SERGENSIO_RTS_ON	1
-#define SERGENSIO_RTS_OFF	2
+#define SERGENSIO_RTS_ON	1u
+#define SERGENSIO_RTS_OFF	2u
 GENSIO_DLL_PUBLIC
 int sergensio_rts(struct sergensio *sio, unsigned int rts,
 		  sergensio_done done, void *cb_data);
 
+/*
+ * Turning CTS off should stop the sender, setting it to auto puts it
+ * under control of the remote system.  This is for a modem-side
+ * connection, like ipmisol.
+ */
+#define SERGENSIO_CTS_AUTO	1u
+#define SERGENSIO_CTS_OFF	2u
+GENSIO_DLL_PUBLIC
+int sergensio_cts(struct sergensio *sio, unsigned int cts,
+		  sergensio_done done, void *cb_data);
+
+/*
+ * Controls the DCD/DSR lines to the remote side.  This is for a modem-side
+ * connection, like ipmisol.
+ */
+#define SERGENSIO_DCD_DSR_ON	1u
+#define SERGENSIO_DCD_DSR_OFF	2u
+GENSIO_DLL_PUBLIC
+int sergensio_dcd_dsr(struct sergensio *sio, unsigned int dcd_dsr,
+		      sergensio_done done, void *cb_data);
+
+/*
+ * Controls the RI (Ring Indicator) line to the remote side.  This is
+ * for a modem-side connection, like ipmisol.
+ */
+#define SERGENSIO_RI_ON		1u
+#define SERGENSIO_RI_OFF	2u
+GENSIO_DLL_PUBLIC
+int sergensio_ri(struct sergensio *sio, unsigned int ri,
+		 sergensio_done done, void *cb_data);
+
 GENSIO_DLL_PUBLIC
 int sergensio_signature(struct sergensio *sio,
 			const char *sig, unsigned int len,
@@ -148,11 +184,15 @@ int sergensio_flowcontrol_state(struct sergensio *sio, bool val);
 /*
  * Tell the remote end to flush its buffers.
  */
+#define SERGENSIO_FLUSH_RCV_BUFFER		1
+#define SERGENSIO_FLUSH_XMIT_BUFFER		2
+#define SERGENSIO_FLUSH_RCV_XMIT_BUFFERS	3
+GENSIO_DLL_PUBLIC
+int sergensio_flush(struct sergensio *sio, unsigned int val);
+/* These were misnamed, their use is deprecated. */
 #define SERGIO_FLUSH_RCV_BUFFER		1
 #define SERGIO_FLUSH_XMIT_BUFFER	2
 #define SERGIO_FLUSH_RCV_XMIT_BUFFERS	3
-GENSIO_DLL_PUBLIC
-int sergensio_flush(struct sergensio *sio, unsigned int val);
 
 /*
  * Tell the remote end to send a break.
@@ -191,21 +231,64 @@ void sergensio_b_free(struct sergensio_b *sbio);
 GENSIO_DLL_PUBLIC
 int sergensio_baud_b(struct sergensio_b *sbio, int *baud);
 GENSIO_DLL_PUBLIC
+int sergensio_baud_b_timeout(struct sergensio_b *sbio, int *baud,
+			     gensio_time *timeout);
+GENSIO_DLL_PUBLIC
 int sergensio_datasize_b(struct sergensio_b *sbio, int *datasize);
 GENSIO_DLL_PUBLIC
+int sergensio_datasize_b_timeout(struct sergensio_b *sbio, int *datasize,
+				 gensio_time *timeout);
+GENSIO_DLL_PUBLIC
 int sergensio_parity_b(struct sergensio_b *sbio, int *parity);
 GENSIO_DLL_PUBLIC
+int sergensio_parity_b_timeout(struct sergensio_b *sbio, int *parity,
+			       gensio_time *timeout);
+GENSIO_DLL_PUBLIC
 int sergensio_stopbits_b(struct sergensio_b *sbio, int *stopbits);
 GENSIO_DLL_PUBLIC
+int sergensio_stopbits_b_timeout(struct sergensio_b *sbio, int *stopbits,
+				 gensio_time *timeout);
+GENSIO_DLL_PUBLIC
 int sergensio_flowcontrol_b(struct sergensio_b *sbio, int *flowcontrol);
 GENSIO_DLL_PUBLIC
+int sergensio_flowcontrol_b_timeout(struct sergensio_b *sbio, int *flowcontrol,
+				    gensio_time *timeout);
+GENSIO_DLL_PUBLIC
 int sergensio_iflowcontrol_b(struct sergensio_b *sbio, int *iflowcontrol);
 GENSIO_DLL_PUBLIC
+int sergensio_iflowcontrol_b_timeout(struct sergensio_b *sbio,
+				     int *iflowcontrol,
+				     gensio_time *timeout);
+GENSIO_DLL_PUBLIC
 int sergensio_sbreak_b(struct sergensio_b *sbio, int *breakv);
 GENSIO_DLL_PUBLIC
+int sergensio_sbreak_b_timeout(struct sergensio_b *sbio, int *breakv,
+			       gensio_time *timeout);
+GENSIO_DLL_PUBLIC
 int sergensio_dtr_b(struct sergensio_b *sbio, int *dtr);
 GENSIO_DLL_PUBLIC
+int sergensio_dtr_b_timeout(struct sergensio_b *sbio, int *dtr,
+			    gensio_time *timeout);
+GENSIO_DLL_PUBLIC
 int sergensio_rts_b(struct sergensio_b *sbio, int *rts);
+GENSIO_DLL_PUBLIC
+int sergensio_rts_b_timeout(struct sergensio_b *sbio, int *rts,
+			    gensio_time *timeout);
+GENSIO_DLL_PUBLIC
+int sergensio_cts_b(struct sergensio_b *sbio, int *cts);
+GENSIO_DLL_PUBLIC
+int sergensio_cts_b_timeout(struct sergensio_b *sbio, int *cts,
+			    gensio_time *timeout);
+GENSIO_DLL_PUBLIC
+int sergensio_dcd_dsr_b(struct sergensio_b *sbio, int *dcd_dsr);
+GENSIO_DLL_PUBLIC
+int sergensio_dcd_dsr_b_timeout(struct sergensio_b *sbio, int *dcd_dsr,
+				gensio_time *timeout);
+GENSIO_DLL_PUBLIC
+int sergensio_ri_b(struct sergensio_b *sbio, int *ri);
+GENSIO_DLL_PUBLIC
+int sergensio_ri_b_timeout(struct sergensio_b *sbio, int *ri,
+			   gensio_time *timeout);
 
 /*
  * Events for dynamic changes to the serial port.  Users can ignore these
@@ -218,24 +301,24 @@ int sergensio_rts_b(struct sergensio_b *sbio, int *rts);
  * requested the mask be changed.  buf points to an unsigned integer
  * holding the modem or line state.
  */
-#define GENSIO_EVENT_SER_MODEMSTATE	(SERGENIO_EVENT_BASE + 1)
-#define GENSIO_EVENT_SER_LINESTATE	(SERGENIO_EVENT_BASE + 2)
+#define GENSIO_EVENT_SER_MODEMSTATE	(SERGENSIO_EVENT_BASE + 1)
+#define GENSIO_EVENT_SER_LINESTATE	(SERGENSIO_EVENT_BASE + 2)
 
 /*
  * On the server side, these are for reporting that the client is
  * requesting the signature.  Not for client.
  */
-#define GENSIO_EVENT_SER_SIGNATURE	(SERGENIO_EVENT_BASE + 3)
+#define GENSIO_EVENT_SER_SIGNATURE	(SERGENSIO_EVENT_BASE + 3)
 
 /*
  * The remote end is asking the user to flow control or flush.  Client
  * or server.
  */
-#define GENSIO_EVENT_SER_FLOW_STATE	(SERGENIO_EVENT_BASE + 4)
-#define GENSIO_EVENT_SER_FLUSH		(SERGENIO_EVENT_BASE + 5)
+#define GENSIO_EVENT_SER_FLOW_STATE	(SERGENSIO_EVENT_BASE + 4)
+#define GENSIO_EVENT_SER_FLUSH		(SERGENSIO_EVENT_BASE + 5)
 
 /* Got a sync from the other end.  Client or server. */
-#define GENSIO_EVENT_SER_SYNC		(SERGENIO_EVENT_BASE + 6)
+#define GENSIO_EVENT_SER_SYNC		(SERGENSIO_EVENT_BASE + 6)
 
 /*
  * Server callbacks.  These only come in in server mode, you must
@@ -243,15 +326,15 @@ int sergensio_rts_b(struct sergensio_b *sbio, int *rts);
  * though the done callback is ignored in that case.  buf points to
  * an integer holding the value.
  */
-#define GENSIO_EVENT_SER_BAUD		(SERGENIO_EVENT_BASE + 7)
-#define GENSIO_EVENT_SER_DATASIZE	(SERGENIO_EVENT_BASE + 8)
-#define GENSIO_EVENT_SER_PARITY		(SERGENIO_EVENT_BASE + 9)
-#define GENSIO_EVENT_SER_STOPBITS	(SERGENIO_EVENT_BASE + 10)
-#define GENSIO_EVENT_SER_FLOWCONTROL	(SERGENIO_EVENT_BASE + 11)
-#define GENSIO_EVENT_SER_IFLOWCONTROL	(SERGENIO_EVENT_BASE + 12)
-#define GENSIO_EVENT_SER_SBREAK		(SERGENIO_EVENT_BASE + 13)
-#define GENSIO_EVENT_SER_DTR		(SERGENIO_EVENT_BASE + 14)
-#define GENSIO_EVENT_SER_RTS		(SERGENIO_EVENT_BASE + 15)
+#define GENSIO_EVENT_SER_BAUD		(SERGENSIO_EVENT_BASE + 7)
+#define GENSIO_EVENT_SER_DATASIZE	(SERGENSIO_EVENT_BASE + 8)
+#define GENSIO_EVENT_SER_PARITY		(SERGENSIO_EVENT_BASE + 9)
+#define GENSIO_EVENT_SER_STOPBITS	(SERGENSIO_EVENT_BASE + 10)
+#define GENSIO_EVENT_SER_FLOWCONTROL	(SERGENSIO_EVENT_BASE + 11)
+#define GENSIO_EVENT_SER_IFLOWCONTROL	(SERGENSIO_EVENT_BASE + 12)
+#define GENSIO_EVENT_SER_SBREAK		(SERGENSIO_EVENT_BASE + 13)
+#define GENSIO_EVENT_SER_DTR		(SERGENSIO_EVENT_BASE + 14)
+#define GENSIO_EVENT_SER_RTS		(SERGENSIO_EVENT_BASE + 15)
 
 GENSIO_DLL_PUBLIC
 bool sergensio_is_client(struct sergensio *sio);
